%define ALD_Ver		2.0

#USE gcc-7.5.0

%define OrgName util-linux
%define mC_Version 1.2.4s

Name:         mC-%{OrgName}-box
License:      GPL
Summary:      Basic util-linux module
Version:      2.36.2
Release:      %{mC_Version}.0

#Source: https://www.kernel.org/pub/linux/utils/util-linux

Source: %{OrgName}-%{version}.tar.xz
Source1: %{OrgName}-box-%{version}-patches.tgz

%define DestDir /Embedded/mC/%{mC_Version}
# -----------------------------------------------------
%define auto_local %{_sourcedir}/AUTO_LOCAL-1.sh
%define have_auto_local %(if test -x %{auto_local} ; then echo 1 ; else echo 0 ; fi)

%if %{_target_cpu} == %{_build_cpu}
%define _srcrpmdir	%{_topdir}/SRPMS/%{ALD_Ver}/mC/%{mC_Version}
%define _CROSS 0
%else
# rpm --target=x86_64 -ba xxxxx.spec
%define _srcrpmdir	%{_topdir}/SRPMS/tmp
%define _CROSS 1
%endif

# -----------------------------------------------------

%if %{have_auto_local}
%define __os_install_post %{nil}
%endif

%if %{_CROSS}
%define CrossPath /cross/%{_target_cpu}
%else
%define CrossPath %{nil}
%endif

#------------------ CROSS DIR --------------------

%define _prefix /usr/mC/%{mC_Version}
%define _mandir /usr/share/man
%define docdir %{_defaultdocdir}/%{OrgName}
%define target %{_arch}-linux-musl

# ------------------- description ------------------------------------
%description
Basic util-linux module
#-------------------------------
%package mount
Summary:      Basic system mount / umount
%description mount
Basic system mount / umount
#-------------------------------
%package cfdisk
Summary:      Basic system
%description cfdisk
Basic system
#-------------------------------
%package fdisk
Summary:      Basic system fdisk / sfdisk
%description fdisk
Basic system fdisk / sfdisk
#-------------------------------
%package fstrim
Summary:      Basic system
%description fstrim
Basic system
#-------------------------------
%package eject
Summary:      Basic system
%description eject
Basic system
#-------------------------------
%package devel
Summary:      Libraries for the C compiler
%description devel
These libraries are needed to compile C code.

# ------------------- setup ------------------------------------------
%Prep
%setup -q -n %{OrgName}-%{version}

tar -xzf %SOURCE1
patch -b -z .orig -p0<patches/util-linux-box.patch
patch -b -z .orig -p0<patches/enable_fstrim.patch

# ------------------- Build ------------------------------------------
%Build
export PATH=$PATH:%{CrossPath}%{_prefix}/bin
export GCC_NoHostPath=d

%if %{_arch} == "i386"
OPTFLAGS="-Os -march=i586 -mpreferred-stack-boundary=2 -falign-functions=1 -falign-jumps=1 -falign-loops=1 -fomit-frame-pointer"
%endif
%if %{_arch} == "x86_64"
OPTFLAGS="-Os"
%endif
%if %{_arch} == "arm"
OPTFLAGS="%{optflags} -Os -munaligned-access"
%endif

OPTFLAGS="$OPTFLAGS -fno-asynchronous-unwind-tables -ffunction-sections -fdata-sections"
export CFLAGS="$OPTFLAGS -std=gnu99"
export LDFLAGS="-Wl,--gc-sections"
export CC="%{target}-gcc"

./configure \
	--prefix=%{_prefix} \
	--exec-prefix=%{_exec_prefix} \
	--bindir=%{_bindir} \
	--sbindir=%{_sbindir} \
	--sysconfdir=%{_sysconfdir} \
	--datadir=%{_datadir} \
	--includedir=%{_includedir} \
	--libdir=%{_libdir} \
	--libexecdir=%{_libexecdir} \
	--localstatedir=%{_localstatedir} \
	--sharedstatedir=%{_sharedstatedir} \
	--mandir=%{_mandir} \
	--infodir=%{_infodir} \
	--enable-static \
	--disable-shared \
	--disable-libtool-lock \
	--disable-symvers \
	--disable-gtk-doc \
	--disable-nls \
	--disable-all-programs \
	--disable-widechar \
	--without-ncursesw \
	--enable-libuuid \
	--enable-libblkid \
	--enable-libmount \
	--enable-libsmartcols \
	--enable-libfdisk \
	--enable-mount \
	--enable-fdisks \
	--enable-eject \
	--disable-bash-completion \
	--disable-pg-bell \
	--disable-colors-default \
	--without-user \
	--without-systemd \
	--without-econf \
	--without-python \
  &>FConfigure_log.txt

make V=1 &>FMake_log.txt

cd box
make &>FMake_log_box.txt
cd ..

# ------------------- Install ----------------------------------------
%Install
export PATH=$PATH:%{CrossPath}%{_prefix}/bin
export GCC_NoHostPath=d

rm -rf $RPM_BUILD_ROOT
mkdir -p %{_srcrpmdir}
mkdir -p $RPM_BUILD_ROOT%{docdir}

make DESTDIR=$RPM_BUILD_ROOT install &>FInstall_log.txt

rm $RPM_BUILD_ROOT%{_libdir}/*.la

cp README $RPM_BUILD_ROOT%{docdir}/
ln -s /usr/share/doc/gpl-2.0.txt $RPM_BUILD_ROOT%{docdir}/COPYING

rm -r $RPM_BUILD_ROOT%{_datadir}/bash-completion
rm -r $RPM_BUILD_ROOT%{_mandir}/man3
rm -r $RPM_BUILD_ROOT%{_mandir}/man5
rm -r $RPM_BUILD_ROOT%{_bindir}
rm -r $RPM_BUILD_ROOT%{_sbindir}

cd box
make DESTDIR=$RPM_BUILD_ROOT install
cd ..

%if %{have_auto_local}
  %{auto_local} -build_cpu=%{_build_cpu} -target_cpu=%{_target_cpu} \
	-target_platform=%{target}-
%endif  # have_auto_local

# ------------------- Clean ------------------------------------------
%Clean
%if %{have_auto_local}
  %{auto_local} -build_cpu=%{_build_cpu} -target_cpu=%{_target_cpu} \
	-ALD_Ver=%{ALD_Ver} -RpmMovePath=%{DestDir} -tar_arg=bzip2
%endif  # have_auto_local

# ------------------- Files ------------------------------------------
%files
/sbin/util-linux-box
%{docdir}

%files mount
/bin/mount
/bin/umount
%{_mandir}/man8/mount.*
%{_mandir}/man8/umount.*

%files cfdisk
/sbin/cfdisk
%{_mandir}/man8/cfdisk.*

%files fdisk
/sbin/fdisk
/sbin/sfdisk
%{_mandir}/man8/fdisk.*
%{_mandir}/man8/sfdisk.*

%files fstrim
/sbin/fstrim
%{_mandir}/man8/fstrim.*

%files eject
/usr/bin/eject
%{_mandir}/man1/eject.*

%files devel
%{_includedir}
%{_libdir}/*.a
%{_libdir}/pkgconfig
